<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Skriveni prečaci</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Programski kodirani prečaci će se poništiti ako su također dodijeljeni drugim radnjama u Postavke → Prečaci.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Prečac</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Radnja</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Zatvori prozor ili izađi iz cjeloekranskog prikaza</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Sljedeća slika</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Razmaknica</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Kraj</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Zadnja slika</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Prethodna slika</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Povratna tipka</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Početna mapa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Prva slika</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Počni u cjeloekranskom prikazu (može biti korisno za dijeljenje upraviteljača prozora na ekranu)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Snimi sliku ekrana (zastarjelo, umjesto toga koristi screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>MAPA</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Snimi sliku ekrana i spremi je u mapu bez prikazivanja korisničkog sučelja (zastarjelo, umjesto toga koristi screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[DATOTEKA1, DATOTEKA2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>odgovor nepoznate greške</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>odgovor nepoznate greške</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>odgovor nepoznate greške</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>About</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>A simple and fast image viewer</source>
        <translation>Jednostavan i brz program za prikaz slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Copyright (C) </source>
        <translation>Autorska prava (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>2013-2021</source>
        <translation>2013. – 2021.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>LXQt Project</source>
        <translation>Projekt LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Development: </source>
        <translation>Razvoj: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Open File</source>
        <translation>Otvori datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Image files (%1)</source>
        <translation>Datoteke slika (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Open directory</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Save File</source>
        <translation>Spremi datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="772"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Učitavanje …) – Prikazivač slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="778"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Neuspjelo učitavanje) – Prikazivač slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2 × %3) – Prikazivač slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Prikazivač slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Thumbnails</source>
        <translation>Sličice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1322"/>
        <source>EXIF Data</source>
        <translation>EXIF podaci</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Izbriši</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Koristi modifikacijsku tipku za brisanje
prečaca u modusu uređivanja.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="334"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Upozorenje: Otkriven je nejednoznačan prečac!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="351"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nejednoznačan prečac nije prihvaćen.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Nije moguće spremiti s ovim slikovnim formatom!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Veličina:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Putanja:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Prikazivač slika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <location filename="../mainwindow.ui" line="671"/>
        <source>Annotations Toolbar</source>
        <translation>Traka s napomenama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>&amp;About</source>
        <translation>&amp;Informacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Save</source>
        <translation>&amp;Spremi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Save &amp;As</source>
        <translation>Spremi &amp;kao</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Zoom &amp;In</source>
        <translation>U&amp;većaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;Out</source>
        <translation>U&amp;manji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Kopiraj u međuspremnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Next File</source>
        <translation>Slijedeća datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Previous File</source>
        <translation>Prethodna datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Otvori &amp;s …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Nedavno otvorene datoteke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>&amp;Skriveni prečaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>&amp;Open…</source>
        <translation>&amp;Otvori …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Reload File</source>
        <translation>Ponovo &amp;učitaj datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>PgDown</source>
        <translation>Stranicu dolje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>PgUp</source>
        <translation>Stranicu gore</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>Original Size</source>
        <translation>Izvorna veličina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Fit</source>
        <translation>&amp;Prilagodi veličinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Okreni na&amp;desno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>R</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Okreni na&amp;lijevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>P&amp;references</source>
        <translation>O&amp;sobitosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>&amp;Print</source>
        <translation>Is&amp;pis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>First File</source>
        <translation>Prva datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Home</source>
        <translation>Početak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Last File</source>
        <translation>Zadnja datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>End</source>
        <translation>Kraj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>&amp;New Window</source>
        <translation>&amp;Novi prozor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Preokreni &amp;vodoravno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>H</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Capture Screenshot</source>
        <translation>Snimi ekran</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Cjeloekranski prikaz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Flip &amp;Vertically</source>
        <translation>Preokreni &amp;okomito</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>V</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Umetni iz međuspremnika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Prezentacija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>&amp;Delete</source>
        <translation>&amp;Izbriši</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <source>Show Thumbnails</source>
        <translation>Prikaži sličice</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>T</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>File Properties</source>
        <translation>Svojstva dototeke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>Open &amp;Directory</source>
        <translation>Otvori &amp;mapu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Upload</source>
        <translation>Prenesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Upload the image</source>
        <translation>Prenesi sliku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Ctrl+U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Show EXIF Data</source>
        <translation>Prikaži EFIX podatke</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>No Tool</source>
        <translation>Bez alata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Deselect all drawing tools</source>
        <translation>Odznači sve alate za crtanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Draw Arrow</source>
        <translation>Crtaj strelicu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw an arrow</source>
        <translation>Crtaj strelicu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw Rectangle</source>
        <translation>Crtaj pravokutnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw a hollow rectangle</source>
        <translation>Crtaj prazan pravokutnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw Circle</source>
        <translation>Crtaj krug</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw a hollow circle</source>
        <translation>Crtaj prazan krug</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw Number</source>
        <translation>Crtaj broj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="635"/>
        <source>Draw incrementing numbers</source>
        <translation>Crtaj rastuće brojeve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Menubar</source>
        <translation>Traka izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="649"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Glavna traka alata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Main Toolbar</source>
        <translation>Glavna traka alata</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Traka s napomenama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="679"/>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Show Outline</source>
        <translation>Prikaži konturu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>O</source>
        <translation>K</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopiraj pu&amp;tanju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>Copy path</source>
        <translation>Kopiraj putanju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="710"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Resize</source>
        <translation>Promijeni veličinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Idi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Pogled</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Toolbar</source>
        <translation>Traka alata</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Postavke</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema ikona:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Ograničenje veličine datoteke sličice:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Normalna boja pozadine:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Cjeloekranska boja pozadine:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Maks. broj nedavno otvorenih datoteka:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <source>Slide show interval (seconds):</source>
        <translation>Vremenski razmak između slajdova (s):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>Show image outline by default</source>
        <translation>Standardno prikaži konturu slike</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Standardno prikaži traku s napomenama</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Fit images when navigating</source>
        <translation>Prilagodi veličinu slika tijekom navigacije</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimenzije sličice:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Koristi smeće sustava (i nemoj pitati)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Prozor</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Standardno prikaži ploču sličica</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Standardno prikaži ploču Exif podataka</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Standardno prikaži traku izbornika</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Standardno prikaži glavnu traku alata</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Slika</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="207"/>
        <source>Smooth images on zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>Shortcuts</source>
        <translation>Prečaci</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="234"/>
        <source>Action</source>
        <translation>Radnja</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="239"/>
        <source>Shortcut</source>
        <translation>Prečac</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="247"/>
        <source>Default</source>
        <translation>Standardno</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Opće</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Promijeni veličinu slike</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Visina</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Trenutačna veličina:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Nova veličina:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Zadrži omjer</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Snimka ekrana</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Snimi ekran</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Područje</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Cijeli ekran</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Samo trenutačni prozor</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Snimi područje na ekranu</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Uključi pokazivač miša</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Odgoda:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Uključi naslov prozora i okvir</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Prenesi</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
</context>
</TS>
